@@ -6,7 +6,7 @@
  *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
- * Copyright (c) 2000-2004.2007 Kenneth J. Pronovici.
+ * Copyright (c) 2000-2004.2007,2013 Kenneth J. Pronovici.
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -149,7 +149,7 @@
 #define GNU_URL            ("http://www.gnu.org/")
 
 /** Copyright year range */
-#define COPYRIGHT_DATE     ("2000-2004")
+#define COPYRIGHT_DATE     ("2000-2004,2007,2013")
 
 /** Name of author */
 #define AUTHOR             ("Kenneth J. Pronovici")
@@ -561,15 +561,18 @@ static void print_banner(char **banner)
 
 static void usage(char *program)
 {
-   printf("Usage: %s [string | --help]\n"
+   printf("Usage: %s string\n"
           "\n"
-          "Prints a \"banner\" version of a string to STDOUT.  If $COLUMNS is\n"
-          "set in the environment, it is taken to be the width of the terminal.\n"
-          "Otherwise, a terminal width of %d characters is assumed, and banners\n"
+          "This is a classic-style banner program similar to the one found in Solaris or\n"
+          "AIX in the late 1990s.  It prints a short string to the console in very large\n"
+          "letters.\n"
+          "\n"
+          "If $COLUMNS is exported in the environment, it is taken to be the width of the\n"
+          "terminal. Otherwise, a terminal width of %d characters is assumed, and banners\n"
           "that do not fit will be truncated.\n"
           "\n"
           "This is %s %s.\n"
-          "$LastChangedDate: 2007-02-26 21:10:13 -0600 (Mon, 26 Feb 2007) $.\n"
+          "$LastChangedDate: 2013-04-02 21:20:18 -0500 (Tue, 02 Apr 2013) $.\n"
           "Copyright (c) %s %s <%s>.\n"
           "\n"
           "Distributed under the GNU General Public License.\n"
